InAppLocationConfig class
Behavior knobs for InAppLocationKit and bundled widgets.
Constructors
- InAppLocationConfig({Duration gpsStabilizeDelay = const Duration(seconds: 2), LocationAccuracy accuracy = LocationAccuracy.medium, Duration positionTimeout = const Duration(seconds: 18), bool reverseGeocode = true, PermissionBackend permissionBackend = PermissionBackend.auto, bool requestPermissionOnGpsEnable = true, bool openAppSettingsOnDeniedForever = true, String? addressFormatter(Placemark place)?, LocationAnalyticsCallbacks? analytics})
-
const
Properties
- accuracy → LocationAccuracy
-
final
- addressFormatter → String? Function(Placemark place)?
-
Build display address from
Placemark. Return null to use default format.final - analytics → LocationAnalyticsCallbacks?
-
final
- gpsStabilizeDelay → Duration
-
Khaugalli-style wait after user enables GPS before fetching fix.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locationSettings → LocationSettings
-
no setter
- openAppSettingsOnDeniedForever → bool
-
final
- permissionBackend → PermissionBackend
-
final
- positionTimeout → Duration
-
final
- requestPermissionOnGpsEnable → bool
-
After
Location.requestService, also call geolocator permission (iOS).final - reverseGeocode → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const InAppLocationConfig