InAppLocationMapScreen class

Map pin picker (Khaugalli SetLocationScreen-style).

Set mapsEnabled to false (or omit googleMapsApiKey) when the host app has not configured a native Google Maps API key — avoids a hard crash.

Inheritance

Constructors

InAppLocationMapScreen({Key? key, required void onConfirm(LocationFixResult result), LocationKitBase? kit, LatLng? initialPosition, InAppLocationStrings strings = const InAppLocationStrings(), InAppLocationTheme theme = const InAppLocationTheme(), String appBarTitle = 'Set location', String? googleMapsApiKey, bool mapsEnabled = true, String? mapsSetupHint})
const

Properties

appBarTitle String
final
googleMapsApiKey String?
If set, mapsEnabled is derived from MapsAvailability.isConfigured.
final
hashCode int
The hash code for this object.
no setterinherited
initialPosition → LatLng?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
kit LocationKitBase?
final
mapsEnabled bool
When false, shows MapsUnavailablePlaceholder instead of GoogleMap.
final
mapsSetupHint String?
final
onConfirm → void Function(LocationFixResult result)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strings InAppLocationStrings
final
theme InAppLocationTheme
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<InAppLocationMapScreen>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited